# word-starts-with

Find a word that starts with something

Created for [r/askouija](https://www.reddit.com/r/askouija).

## Usage

### Simple one word usage

```cmd
python -m wsw [text]
```

or

```cmd
wsw [text]
```

Where `[text]` is the text you want to check.

### Interactive session

```cmd
wsw
```

This will start a interactive session where you can put words again and again
![Example](https://i.imgur.com/uXwwbp3.png)

You can exit out of this by using Ctrl+C

### Saving output to a file

You can just append a `> filename` at the end of the command to pipe the output to a file e.g. `wsw [text] > text.txt`
